==> apache-servicecomb-java-chassis-distribution-2.1.1-src.zip: apache-servicecomb-java-chassis-distribution-2.1.1-src/inspector/src/main/java/org/apache/servicecomb/inspector/internal/InspectorConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.inspector.internal;

import org.apache.servicecomb.config.inject.InjectProperties;
import org.apache.servicecomb.config.inject.InjectProperty;

@InjectProperties(prefix = "servicecomb.inspector")
public class InspectorConfig {
  @InjectProperty(keys = "enabled", defaultValue = "true")
  private boolean enabled;

  @InjectProperty(keys = "swagger.html.asciidoctorCss", defaultValue = "https://cdnjs.cloudflare.com/ajax/libs/asciidoctor.js/1.5.9/css/asciidoctor.css")
  private String asciidoctorCss;

  public boolean isEnabled() {
    return enabled;
  }

  public void setEnabled(boolean enabled) {
    this.enabled = enabled;
  }

  public String getAsciidoctorCss() {
    return asciidoctorCss;
  }

  public void setAsciidoctorCss(String asciidoctorCss) {
    this.asciidoctorCss = asciidoctorCss;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.3.5-src.zip: apache-servicecomb-java-chassis-distribution-2.3.5-src/inspector/src/main/java/org/apache/servicecomb/inspector/internal/InspectorConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.inspector.internal;

import org.apache.servicecomb.config.inject.InjectProperties;
import org.apache.servicecomb.config.inject.InjectProperty;
import org.springframework.stereotype.Component;

@Component
@InjectProperties(prefix = "servicecomb.inspector")
public class InspectorConfig {
  @InjectProperty(keys = "enabled", defaultValue = "true")
  private boolean enabled;

  @InjectProperty(keys = "swagger.html.asciidoctorCss", defaultValue = "https://cdnjs.cloudflare.com/ajax/libs/asciidoctor.js/1.5.9/css/asciidoctor.css")
  private String asciidoctorCss;

  public boolean isEnabled() {
    return enabled;
  }

  public InspectorConfig setEnabled(boolean enabled) {
    this.enabled = enabled;
    return this;
  }

  public String getAsciidoctorCss() {
    return asciidoctorCss;
  }

  public InspectorConfig setAsciidoctorCss(String asciidoctorCss) {
    this.asciidoctorCss = asciidoctorCss;
    return this;
  }
}
